@@ -1,14 +1,23 @@
-test_that("pars_term", {
+test_that("pars_term term", {
   terms <- new_term(c(
     "alpha[1]", "alpha[2]", "beta[1,1]", "beta[2,1]",
     "beta[1,2]", "beta[2,2]", "sigma"
   ))
-  rlang::with_options(lifecycle_verbosity = "quiet", {
-  expect_identical(pars_terms(terms, scalar = TRUE), "sigma")
-    })
-  rlang::with_options(lifecycle_verbosity = "quiet", {
-  expect_identical(pars_terms(terms, scalar = FALSE), c("alpha", "alpha", "beta",  "beta",  "beta",  "beta"))
-    })
+  lifecycle::expect_deprecated(pars_terms(terms, scalar = TRUE))
+  lifecycle::expect_deprecated(pars_terms(terms, scalar = FALSE))
+  expect_identical(
+    pars_terms(terms),
+    c("alpha", "alpha", "beta", "beta", "beta", "beta", "sigma")
+  )
+})
+
+test_that("pars_term term_rcrd", {
+  terms <- as_term_rcrd(new_term(c(
+    "alpha[1]", "alpha[2]", "beta[1,1]", "beta[2,1]",
+    "beta[1,2]", "beta[2,2]", "sigma"
+  )))
+  lifecycle::expect_deprecated(pars_terms(terms, scalar = TRUE))
+  lifecycle::expect_deprecated(pars_terms(terms, scalar = FALSE))
   expect_identical(
     pars_terms(terms),
     c("alpha", "alpha", "beta", "beta", "beta", "beta", "sigma")
